##########
Validators
##########

Built in validators
===================

These validators are provided with *odin*.

.. automodule:: odin.validators

    .. autoclass:: RegexValidator

    .. autoclass:: URLValidator

    .. autoclass:: MaxValueValidator

    .. autoclass:: MinValueValidator

    .. autoclass:: LengthValidator

    .. autoclass:: MaxLengthValidator

    .. autoclass:: MinLengthValidator


    Odin also includes a helper method for generating simple validators.

    .. autofunction:: simple_validator

